==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/PMSCHEDULEACTID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PPMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYNOTE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "ppmid",
    "activitycode",
    "activitynote"
})
@XmlRootElement(name = "PMSCHEDULEACTID")
public class PMSCHEDULEACTID {

    @XmlElement(name = "PPMID", required = true)
    protected PPM_Type ppmid;
    @XmlElement(name = "ACTIVITYCODE", required = true)
    protected ACTIVITYCODE activitycode;
    @XmlElement(name = "ACTIVITYNOTE")
    protected String activitynote;

    /**
     * Obtient la valeur de la propriété ppmid.
     * 
     * @return
     *     possible object is
     *     {@link PPM_Type }
     *     
     */
    public PPM_Type getPPMID() {
        return ppmid;
    }

    /**
     * Définit la valeur de la propriété ppmid.
     * 
     * @param value
     *     allowed object is
     *     {@link PPM_Type }
     *     
     */
    public void setPPMID(PPM_Type value) {
        this.ppmid = value;
    }

    /**
     * Obtient la valeur de la propriété activitycode.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public ACTIVITYCODE getACTIVITYCODE() {
        return activitycode;
    }

    /**
     * Définit la valeur de la propriété activitycode.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public void setACTIVITYCODE(ACTIVITYCODE value) {
        this.activitycode = value;
    }

    /**
     * Obtient la valeur de la propriété activitynote.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getACTIVITYNOTE() {
        return activitynote;
    }

    /**
     * Définit la valeur de la propriété activitynote.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setACTIVITYNOTE(String value) {
        this.activitynote = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/PMSCHEDULEACTID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PPMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYNOTE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "ppmid",
    "activitycode",
    "activitynote"
})
@XmlRootElement(name = "PMSCHEDULEACTID")
public class PMSCHEDULEACTID {

    @XmlElement(name = "PPMID", required = true)
    protected PPM_Type ppmid;
    @XmlElement(name = "ACTIVITYCODE", required = true)
    protected ACTIVITYCODE activitycode;
    @XmlElement(name = "ACTIVITYNOTE")
    protected String activitynote;

    /**
     * Gets the value of the ppmid property.
     * 
     * @return
     *     possible object is
     *     {@link PPM_Type }
     *     
     */
    public PPM_Type getPPMID() {
        return ppmid;
    }

    /**
     * Sets the value of the ppmid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PPM_Type }
     *     
     */
    public void setPPMID(PPM_Type value) {
        this.ppmid = value;
    }

    /**
     * Gets the value of the activitycode property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public ACTIVITYCODE getACTIVITYCODE() {
        return activitycode;
    }

    /**
     * Sets the value of the activitycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public void setACTIVITYCODE(ACTIVITYCODE value) {
        this.activitycode = value;
    }

    /**
     * Gets the value of the activitynote property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getACTIVITYNOTE() {
        return activitynote;
    }

    /**
     * Sets the value of the activitynote property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setACTIVITYNOTE(String value) {
        this.activitynote = value;
    }

}
